import React, { useState, useEffect } from 'react';
import { Card, CardContent, CardHeader, CardTitle } from "@/components/ui/card";
import { Loader2 } from "lucide-react";
import { AlertCircle } from "lucide-react";
import { Alert, AlertDescription } from "@/components/ui/alert";

const BinanceMarketTable = () => {
  const [data, setData] = useState([]);
  const [loading, setLoading] = useState(true);
  const [error, setError] = useState(null);

  useEffect(() => {
    fetchData();
  }, []);

  const fetchData = async () => {
    try {
      const baseUrl = "https://api.binance.com/api/v3";
      
      // 获取交易对信息
      const exchangeInfo = await fetch(`${baseUrl}/exchangeInfo`).then(res => res.json());
      const usdtPairs = exchangeInfo.symbols
        .filter(s => s.symbol.endsWith('USDT') && s.status === 'TRADING')
        .map(s => s.symbol);

      // 获取24小时数据
      const ticker24hr = await fetch(`${baseUrl}/ticker/24hr`).then(res => res.json());
      const usdtData = ticker24hr.filter(t => usdtPairs.includes(t.symbol));

      // 处理数据
      const processedData = usdtData.map(item => ({
        symbol: item.symbol.replace('USDT', ''),
        price: parseFloat(item.lastPrice),
        volume24h: (parseFloat(item.quoteVolume) / 10000).toFixed(2), // 转换为万USDT
        high24h: parseFloat(item.highPrice),
        low24h: parseFloat(item.lowPrice),
        priceChange: parseFloat(item.priceChangePercent)
      }));

      setData(processedData.sort((a, b) => b.volume24h - a.volume24h));
      setLoading(false);
    } catch (err) {
      setError("获取数据失败，请稍后重试");
      setLoading(false);
    }
  };

  if (loading) {
    return (
      <div className="flex items-center justify-center h-64">
        <Loader2 className="h-8 w-8 animate-spin text-blue-500" />
      </div>
    );
  }

  if (error) {
    return (
      <Alert variant="destructive" className="mb-4">
        <AlertCircle className="h-4 w-4" />
        <AlertDescription>{error}</AlertDescription>
      </Alert>
    );
  }

  return (
    <Card className="w-full">
      <CardHeader>
        <CardTitle>币安USDT交易对行情</CardTitle>
      </CardHeader>
      <CardContent>
        <div className="overflow-x-auto">
          <table className="w-full">
            <thead>
              <tr className="border-b">
                <th className="p-2 text-left">币种</th>
                <th className="p-2 text-right">价格(USDT)</th>
                <th className="p-2 text-right">24h成交额(万USDT)</th>
                <th className="p-2 text-right">24h最高</th>
                <th className="p-2 text-right">24h最低</th>
                <th className="p-2 text-right">24h涨跌幅</th>
              </tr>
            </thead>
            <tbody>
              {data.map((item) => (
                <tr key={item.symbol} className="border-b hover:bg-gray-50">
                  <td className="p-2 font-medium">{item.symbol}</td>
                  <td className="p-2 text-right">{item.price.toFixed(4)}</td>
                  <td className="p-2 text-right">{item.volume24h}</td>
                  <td className="p-2 text-right">{item.high24h}</td>
                  <td className="p-2 text-right">{item.low24h}</td>
                  <td className={`p-2 text-right ${
                    item.priceChange >= 0 ? 'text-green-600' : 'text-red-600'
                  }`}>
                    {item.priceChange >= 0 ? '+' : ''}{item.priceChange}%
                  </td>
                </tr>
              ))}
            </tbody>
          </table>
        </div>
      </CardContent>
    </Card>
  );
};

export default BinanceMarketTable;
